# EnergyFlow
![alt-text](https://travis-ci.org/pkomiske/EnergyFlow.svg?branch=master "Travis-CI Build Status")

EnergyFlow is a Python package that computes Energy Flow quantities such as the Energy Flow Polynomials (EFPs) defined in Ref. [1]. The general formula for an EFP is given in terms of its graph G:

<img src="../images/images/EFP_formula.png" alt="Drawing" width="300px" height="65px"/>

 
#### Installation

To install EnergyFlow with pip, simply write:
```sh
pip install energyflow
```

##### References
[1] P.T. Komiske, E.M. Metodiev, and J. Thaler, _Energy Flow Polynomials: A complete linear basis for jet substructure_, _[JHEP __04__ (2018) 013](https://doi.org/10.1007/JHEP04(2018)013)_ [[1712.07124](https://arxiv.org/abs/1712.07124)].
